@@ -177,7 +177,7 @@ class Witter():
 
         #pass the witter ui a reference to this object for callbacks
         self.ui = ui.WitterUI(self)
-        self.ui.setActiveListStore(self.activeAccount.getTimeline(),4)
+        #self.ui.setActiveListStore(self.activeAccount.getTimeline(),4)
         self.ui.theme = self.theme
         self.ui.load_theme_icons()
         self.ui.select_ui_theme(self.theme)
@@ -221,6 +221,8 @@ class Witter():
 
     def updateSelectedView(self, *args):
         #call the get method for whichever liststore we're viewing
+        print "refreshing view"
+        print str(self.ui.getCurrentView())
         curView = self.ui.getCurrentView()
         if (curView == self.ui.TIMELINE_VIEW):
 
@@ -253,16 +255,18 @@ class Witter():
 	self.ui.hideBottomBar()
 	#self.builder.get_object("hbox2").hide_all()
 
-    def enterPressed(self, widget, *args):
+    def enterPressed(self, widget, tweetBox, *args):
         self.ui.showBusy(1)
         print "sending tweet"
-        result = self.activeAccount.newTweet(self.ui.getEntryText(), reply_to_name=self.reply_to_name, reply_to_id=self.reply_to)
+        tweetBuf = tweetBox.get_buffer()
+        tweet = tweetBuf.get_text(tweetBuf.get_start_iter(),tweetBuf.get_end_iter())
+        result = self.activeAccount.newTweet(tweet, reply_to_name=self.reply_to_name, reply_to_id=self.reply_to)
         print "Tweet Sent"
         if (result == True):
             print "Tweet successful"
             hildon.hildon_banner_show_information(self.ui.window, "", "Tweet Successful")
             #tweet successful, clear tweet text
-            self.ui.setTweetText("")
+            tweetBuf.set_text("")
     	    #if we were in the search view, we want to restore the search terms after a tweet
             if (self.ui.getCurrentView == self.ui.SEARCH_VIEW):
     		    self.ui.setTweetText(self.search_terms)
@@ -1012,7 +1016,7 @@ class Witter():
         self.ui.showBusy(1)
         self.ui.hideActionButtons()
         self.ui.hideActionButtons()
-        self.ui.switchViewTo(widget, "user")
+        self.ui.toggle_view_to(widget, "user")
         self.ui.setTweetText(user)
 
         #need to strip the @ symbol from the user before we request their history
@@ -1130,7 +1134,7 @@ class Witter():
 
     def cb_switch_view(self, interface, method, args, user_data):
          if method == 'open_mentions':
-            self.ui.switchViewTo(self.ui.treeview,"mentions")
+            self.ui.toggleviewto("mentions")
             self.ui.window.show()
             #self.ui.window.fullscreen()
             #self.ui.window.setActiveWindow()
@@ -1146,39 +1150,48 @@ class Witter():
          if ((orientation == 'portrait') & (self.ui.orientation != 'Landscape') ):
             print "switching to portrait"
             #self.ui.orientation=orientation
-            self.ui.cell.set_property('wrap-width', 400)
+            #self.ui.cell.set_property('wrap-width', 400)
+            
             self.ui.icon_size = 30
             self.ui.load_theme_icons()
-            self.ui.define_ui_buttons()
+            self.ui.width=400
+            if ((self.ui.activeWin !="home") & (self.ui.activeWin != None)):
+                
+                self.ui.toggleviewto(self.ui.activeWin)
             self.ui.current_orientation = 'portrait'
             
          if ((orientation == 'landscape') & (self.ui.orientation != 'Portrait')):
             print "switching to landscape"
             #self.ui.orientation=orientation
-            self.ui.cell.set_property('wrap-width', 730)
+            #self.ui.cell.set_property('wrap-width', 730)
+            
             self.ui.icon_size = 48
             self.ui.load_theme_icons()
             self.ui.define_ui_buttons()
+            self.ui.width=720
+            if ((self.ui.activeWin !="home") & (self.ui.activeWin != None)):
+                self.ui.toggleviewto(self.ui.activeWin)
+            
             self.ui.hide_portrait_keyboard()
             self.ui.current_orientation = 'landscape'
-         print "refresh current view"
-         curView = self.ui.getCurrentView()  
-         if (curView == self.ui.TIMELINE_VIEW):
-            self.ui.switch_view_to("timeline")
-         elif (curView == self.ui.DM_VIEW):
-            self.ui.switch_view_to("direct")
-         elif (curView == self.ui.MENTIONS_VIEW):
-            self.ui.switch_view_to("mentions")
-         elif (curView == self.ui.PUBLIC_VIEW):
-            self.ui.switch_view_to("public")
-         elif (curView == self.ui.TRENDS_VIEW):
-            self.ui.switch_view_to("trends")
-         elif (curView == self.ui.FRIENDS_VIEW):
-            self.ui.switch_view_to("friends")
-         elif (curView == self.ui.SEARCH_VIEW):
-            self.ui.switch_view_to("search")
-         elif (curView == self.ui.USERHIST_VIEW):
-            self.ui.switch_view_to("user")
+         #print "refresh current view"
+         #curView = self.ui.getCurrentView()  
+         #if (curView == self.ui.TIMELINE_VIEW):
+         #   self.ui.switch_view_to("timeline")
+         #elif (curView == self.ui.DM_VIEW):
+         #   self.ui.switch_view_to("direct")
+         #elif (curView == self.ui.MENTIONS_VIEW):
+         #   self.ui.switch_view_to("mentions")
+         #elif (curView == self.ui.PUBLIC_VIEW):
+         #   self.ui.switch_view_to("public")
+         #elif (curView == self.ui.TRENDS_VIEW):
+         #   self.ui.switch_view_to("trends")
+         #elif (curView == self.ui.FRIENDS_VIEW):
+         #   self.ui.switch_view_to("friends")
+         #elif (curView == self.ui.SEARCH_VIEW):
+         #   self.ui.switch_view_to("search")
+         #elif (curView == self.ui.USERHIST_VIEW):
+         #   self.ui.switch_view_to("user")
             
     def establish_connection(self):
         magic = 0xAA55 
